<!DOCTYPE html>
<html>

<head>
    <meta http-equiv="content-type" content="text/html; charset=utf-8" />
</head>

<body>
    {% for file in files %}
    <a href="{{ url_for('file_download', filename=file) }}">{{ file }}</a><br/>
    {% endfor %}
</body>

</html>