<!DOCTYPE html>
<html>

<head>
    <meta charset="utf-8">
    <meta name="referrer" content="always"/>
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0;"/>
    <script src="/static/jquery-1.11.1.min.js"></script>
    <script src="/static/bootstrap/js/bootstrap.min.js"></script>
    <script src="/static/webuploader/webuploader.min.js"></script>
    <link rel="stylesheet" type="text/css" href="/static/webuploader/webuploader.css">
    <link rel="stylesheet" type="text/css" href="/static/bootstrap/css/bootstrap.min.css">
    <link rel="stylesheet" type="text/css" href="/static/css/frameworks-32dce2faa502c3c56fb7b214ddbb6ec1.css">
    <link rel="stylesheet" type="text/css" href="/static/css/index.css">
</head>

<body>
    <nav class="navbar navbar-default navbar-static-top">
      <div class="container height-full">
        <div class="row height-full">
            <div class="col-xs-3 brand-title height-full">
                <a href="/">
                    <h1>Fast-ft</h1>
                </a>
            </div>
        </div>
      </div>
    </nav>
    <div class="container main-body">
        <div class="row height-full">
            <div class="col-lg-12 height-full">
                <div class="body-content">
                    <img src="/static/images/qrcode/{{ global_inner_ip }}.png" alt="{{ global_inner_ip }}">
                    <div id="progress_topic">
                        <div id="progress" class="progress">
                            <div class="progress-bar progress-bar-striped active" role="progressbar" style="width:50%;">50%</div>
                        </div>
                    </div>
                    <div class="select-picker">
                        <div id="picker" class="float-left">上传</div>
                        <div><a href="{{ url_for("file_list") }}" id="download" class="btn-success float-right">下载</a></div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <script src="/static/js/index.js"></script>
</body>
</html>